import { attendanceRequestList } from "@/app/lib/attendance/action";
import { Box } from "@chakra-ui/react";
import Table from "./component/table";
import { SearchParamProps } from "@/types/searchParams";
import { usersRequestList } from "@/app/lib/users/action";
import { prepareIbcDropdown, prepareUsersDropdown } from "@/utils/common";
import { getIbcRequestList } from "@/app/lib/ibc/action";
import { getRoles } from "@/app/lib/role/action";

export default async function Attendance({ searchParams }: SearchParamProps) {
  const [users, ibcs, roles, attendance] = await Promise.all([
    usersRequestList({ pagination: 'false' }),
    getIbcRequestList({ pagination: "false" }),
    getRoles({ pagination: "false" }),
    attendanceRequestList({ ...searchParams }),
  ]);

  // Prepare data for users dropdown
  const usersDropdown = prepareUsersDropdown(users);

  // Prepare data for IBC dropdown
  const ibcsDropdown = prepareIbcDropdown(ibcs);

  const rolesDropdown = roles?.map((role: any) => ({
    value: role.id,
    label: role.name,
  }));

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      {attendance?.data && <Table data={attendance?.data} users={usersDropdown} ibcs={ibcsDropdown} roles={rolesDropdown} />}
    </Box>
  );
}
